pyvisco.opt
===========

.. automodule:: pyvisco.opt

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      nprony
      plot_fit
      plot_residual
   
   

   
   
   

   
   
   



